@@ -3,8 +3,11 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from foxtail_trainer_api.api.data_set_chunk_api import DataSetChunkApi
 from foxtail_trainer_api.api.job_api import JobApi
 from foxtail_trainer_api.api.ml_model_api import MLModelApi
+from foxtail_trainer_api.api.prediction_task_api import PredictionTaskApi
 from foxtail_trainer_api.api.report_api import ReportApi
 from foxtail_trainer_api.api.training_config_api import TrainingConfigApi
 from foxtail_trainer_api.api.training_result_api import TrainingResultApi
+from foxtail_trainer_api.api.worker_api import WorkerApi
